# OpenNEM Energy Market Data Access

> [!CAUTION]
> This project has been deprecated.

This is the old OpenNEM Python client. For the updated clients see:

-   [openelectricity-python](https://github.com/OpenNEM/openelectricity-python) - The OpenElectricity Python client
-   [openelectricity-typescript](https://github.com/OpenNEM/openelectricity-typescript) - The OpenElectricity Typescript client

For details on the new developer platform see:

-   [OpenElectricity Platform](https://platform.openelectricity.org.au)
-   [OpenElectricity Documentation](https://docs.openelectricity.org.au)
